import click
from pydanclick import from_pydantic

from . import hacker_news, weather


@click.group()
def cli():
    """cron for daily things."""
    pass


@cli.command("weather")
@from_pydantic(weather.ForecastConfig)
def forecast(forecast_config: weather.ForecastConfig):
    try:
        for forecast in weather.forecast(forecast_config):
            response = forecast.expect("forecast request failed")
            print(f"{response.day_name}:\n{response.description}")
    except ValueError as e:
        print(f"error: {e}")


@cli.command("hacker-news")
def top():
    stories = hacker_news.recent_top_stories()
    for item in stories:
        print(f"[{item.score:>4}|{item.diff_for_humans():>12}]: {item.title}")


@cli.command("profile")
def profile():
    pass


@cli.command("tides")
@click.option("--print", "should_print", is_flag=True, default=False)
def tides(should_print: bool):
    import sys

    import duckdb
    import pandas as pd

    from . import tides

    query = """
        WITH cte AS (
            SELECT
                t as day,
                v as height,
                type as type,
                MIN(v) OVER (PARTITION BY date_trunc('DAY', t)) as day_min
            FROM tides
        ), days AS (
            SELECT
                day,
                height,
                type,
                day_min
            FROM cte
            WHERE day_min > 0.8
        )
        SELECT
            strftime(date_trunc('day', day), '%b %d, %Y') as day,
            first(day_min) as day_min
        FROM days
        GROUP BY
            date_trunc('day', day)
        ORDER BY day
    """

    tides = pd.DataFrame((t.model_dump() for t in tides.get_tides()))
    with duckdb.connect() as conn:
        rel = conn.sql(query)
        if should_print:
            print(rel)
        else:
            rel.write_csv("matts_vacation.csv", sep="|")
    sys.exit(0)
    for fields in data.get("predictions"):
        tide = Tide(**fields)
        print(f"{tide.t}: {tide.v} ({tide.type})")
