import sys
from datetime import datetime

import duckdb
import pandas as pd
import requests
import requests_cache
from pydantic import BaseModel
from typing import Iterable


class Tide(BaseModel):
    t: datetime
    v: float
    type: str


def get_tides(start=20250216, end=20251231) -> Iterable[Tide]:
    url = f"https://api.tidesandcurrents.noaa.gov/api/prod/datagetter?product=predictions&format=json&interval=hilo&time_zone=LST_LDT&units=english&datum=MLLW&station=9449211&begin_date={start}&end_date={end}"

    session = requests_cache.CachedSession("tides")
    response = session.get(url)
    match response.status_code:
        case 200:
            data = response.json()
        case _:
            import sys

            sys.exit(0)

    for t in data.get("predictions"):
        yield Tide(**t)
